@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Aug 2002
 ;;;;
-;;;; $Id: base.lisp 8226 2003-11-16 15:49:47Z kevin $
+;;;; $Id: base.lisp 10304 2005-01-29 02:22:15Z kevin $
 ;;;;
 ;;;; This file, part of LML2, is Copyright (c) 2000-2003 by Kevin Rosenberg.
 ;;;; Rights of modification and redistribution are in the LICENSE file.
@@ -79,7 +79,7 @@
 (defmacro html-file-page ((out-file &key (format :xhtml11))
 			  &body body)
   `(with-open-file (*html-stream*
-		    (lml-file-name ,out-file :output)
+		    (lml-file-name ',out-file :output)
 		    :direction :output
 		    :if-exists :supersede)
      (dtd-prologue ,format)
