@@ -27,7 +27,8 @@
   (when (stringp f)
     (unless (position #\. f)
       (setq f (concatenate 'string f ".html"))))
-  (if *sources-dir*
+  (if (or (and (eq type :source) *sources-dir*)
+	  (and (eq type :output) *output-dir*))
       (merge-pathnames
        (make-pathname :name (pathname-name f)
 		      :type (pathname-type f)
